@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -40,8 +38,8 @@ STATS_DEF = OrderedDict(
         ("mail_found", "Total number of mails encountered from all mail sources."),
         (
             "mail_rejected",
-            "Number of mails individuality rejected because they were unparseable or "
-            "did not had enough metadata to compute hashes.",
+            "Number of mails rejected individually because they were unparseable or "
+            "did not have enough metadata to compute hashes.",
         ),
         (
             "mail_retained",
@@ -50,7 +48,7 @@ STATS_DEF = OrderedDict(
         ("mail_hashes", "Number of unique hashes."),
         (
             "mail_unique",
-            "Number of unique mails (which where automaticcaly added to selection).",
+            "Number of unique mails (which where automatically added to selection).",
         ),
         (
             "mail_duplicates",
@@ -60,7 +58,7 @@ STATS_DEF = OrderedDict(
         (
             "mail_skipped",
             "Number of mails ignored in the selection phase because the whole set "
-            "they belongs to was skipped.",
+            "they belong to was skipped.",
         ),
         ("mail_discarded", "Number of mails discarded from the final selection."),
         (
@@ -77,8 +75,8 @@ STATS_DEF = OrderedDict(
         ("set_total", "Total number of duplicate sets."),
         (
             "set_single",
-            "Total number of sets containing a single mail and did not had to have a "
-            "strategy applied to. They were automatticaly kept in the final selection.",
+            "Total number of sets containing only a single mail with no applicable "
+            "strategy. They were automatically kept in the final selection.",
         ),
         (
             "set_skipped_encoding",
@@ -88,12 +86,12 @@ STATS_DEF = OrderedDict(
         (
             "set_skipped_size",
             "Number of sets skipped from the selection process because they were "
-            "too disimilar in size.",
+            "too dissimilar in size.",
         ),
         (
-            "set_skipeed_content",
+            "set_skipped_content",
             "Number of sets skipped from the selection process because they were "
-            "too disimilar in content.",
+            "too dissimilar in content.",
         ),
         (
             "set_skipped_strategy",
@@ -121,8 +119,8 @@ class DuplicateSet:
         """Load-up the duplicate set of mail and freeze pool.
 
         Once loaded-up, the pool of parsed mails is considered frozen for the
-        rest of the duplicate set's life. This allow aggressive caching of lazy
-        instance attributes depending on the pool content.
+        rest of the duplicate set's life. This allows aggressive caching of
+        lazy instance attributes depending on the pool content.
         """
         self.hash_key = hash_key
 
@@ -207,11 +205,9 @@ class DuplicateSet:
                     raise ContentDiffAboveThreshold
 
     def diff(self, mail_a, mail_b):
-        """Return difference in bytes between two mails' normalized body.
-
-        TODO: rewrite the diff algorithm to not rely on naive unified diff
-        result parsing.
-        """
+        # TODO: rewrite the diff algorithm to not rely on naive unified diff
+        # result parsing.
+        """Return difference in bytes between two mails' normalized body."""
         return len(
             "".join(
                 unified_diff(
@@ -331,15 +327,16 @@ class Deduplicate:
         if source_path in self.sources:
             raise ValueError(f"{source_path} already added.")
 
-        # Open and register the mail source.
-        box = open_box(source_path, self.conf.input_format, self.conf.force_unlock)
-        assert source_path == box._path
-        self.sources[source_path] = box
+        # Open and register the mail source. Subfolders will be registered as their
+        # own box.
+        boxes = open_box(source_path, self.conf.input_format, self.conf.force_unlock)
+        for box in boxes:
+            self.sources[box._path] = box
 
-        # Track of global mail count.
-        mail_found = len(box)
-        logger.info(f"{mail_found} mails found.")
-        self.stats["mail_found"] += mail_found
+            # Track global mail count.
+            mail_found = len(box)
+            logger.info(f"{mail_found} mails found.")
+            self.stats["mail_found"] += mail_found
 
     def hash_all(self):
         """Browse all mails from all registered sources, compute hashes and group mails
